====================================================
Structure generators
====================================================

This module contains classes and functions to sample training
structures using existing cluster expansion.

.. toctree::
   :maxdepth: 1

   mc_generators

More to come...
